﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Xml;
using System.Xml.Serialization;

namespace CG.EventXmlDeserialization
{
    [XmlRoot(ElementName = "event", Namespace = "")]
    [XmlType(AnonymousType = true, Namespace = "")]
    public class Event
    {
        public static Event CreateFromXml(string xml)
        {
            var serializer = new XmlSerializer(typeof(Event));

            using (var reader = new StringReader(xml))
            {
                return (Event)serializer.Deserialize(reader);
            }
        }

        [XmlElement("site")]
        public string Site { get; set; }

        [XmlElement("eventid")]
        public Guid EventId { get; set; }

        [XmlElement("eventdata")]
        public EventData Data { get; set; }

        public Event()
        {
            Data = new EventData();
        }
    }

    public class EventData
    {
        [XmlArray("currencies")]
        [XmlArrayItem("currency")]
        public Currency[] Currencies
        {
            set { if (value != null) { _currencies.AddRange(value); } }
            get { return _currencies.ToArray(); }
        }

        public EventData()
        {
            _currencies = new List<Currency>();
        }

        private List<Currency> _currencies;
    }

    public class Currency
    {
        [XmlElement("isocode")]
        public string IsoCode { get; set; }
        
        [XmlElement("bankbuyrate")]
        public decimal BankBuyRate { get; set; }
        
        [XmlElement("banksellrate")]
        public decimal BankSellRate { get; set; }
        
        [XmlElement("STAFFbuyrate")]
        public decimal StaffBuyRate { get; set; }
        
        [XmlElement("STAFFsellrate")]
        public decimal StaffSellRate { get; set; }
        
        [XmlElement("displayname")]
        public string DisplayName { get; set; }
        
        [XmlElement("decimaldigits")]
        public int DecimalDigits { get; set; }
    }
}
